"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@babel/core");
var index_1 = __importDefault(require("../index"));
var babelOpts = {
    configFile: false,
    babelrc: false,
    plugins: ['@babel/plugin-syntax-jsx', index_1.default],
};
describe('babel plugin', function () {
    it('should not change code where there is no compiled components', function () {
        var _a;
        var output = core_1.transformSync("\n      const one = 1;\n    ", babelOpts);
        expect((_a = output) === null || _a === void 0 ? void 0 : _a.code).toEqual('const one = 1;');
    });
    it('should transform a styled component', function () {
        var _a;
        var output = core_1.transformSync("\n      import { styled } from '@compiled/css-in-js';\n\n      styled.div`\n        font-size: 12px;\n      `;\n    ", babelOpts);
        expect((_a = output) === null || _a === void 0 ? void 0 : _a.code).toMatchInlineSnapshot("\n      \"import React from \\\"react\\\";\n      import { Style, styled } from '@compiled/css-in-js';\n\n      props => <><Style hash=\\\"css-1x3e11p\\\">{[\\\".css-1x3e11p{font-size:12px;}\\\"]}</Style><div {...props} className={\\\"css-1x3e11p\\\" + (props.className ? \\\" \\\" + props.className : \\\"\\\")}></div></>;\"\n    ");
    });
    it('should transform css prop', function () {
        var _a;
        var output = core_1.transformSync("\n      /** @jsx jsx */\n      import { jsx } from '@compiled/css-in-js';\n\n      <div css={{ fontSize: 12 }} />\n    ", babelOpts);
        expect((_a = output) === null || _a === void 0 ? void 0 : _a.code).toMatchInlineSnapshot("\n      \"import React from \\\"react\\\";\n      /** @jsx jsx */\n\n      import { Style, jsx } from '@compiled/css-in-js';\n      <><Style hash=\\\"css-1iqe21w\\\">{[\\\".css-1iqe21w{font-size:12px;}\\\"]}</Style><div className=\\\"css-1iqe21w\\\" /></>;\"\n    ");
    });
    it('should transform classnames component', function () {
        var _a;
        var output = core_1.transformSync("\n      import { ClassNames } from '@compiled/css-in-js';\n\n      <ClassNames>\n        {({ css }) => <div className={css({ fontSize: 12 })} />}\n      </ClassNames>\n    ", babelOpts);
        expect((_a = output) === null || _a === void 0 ? void 0 : _a.code).toMatchInlineSnapshot("\n      \"import { Style, ClassNames } from '@compiled/css-in-js';\n      <><Style hash=\\\"css-2lhdif\\\">{[\\\".css-1iqe21w{font-size:12px;}\\\"]}</Style><div className={\\\"css-1iqe21w\\\"} /></>;\"\n    ");
    });
});
//# sourceMappingURL=index.test.js.map